@@ -25,14 +25,15 @@ sub start {
 sub preprocess_req {
         my ($self, $req, $t) = @_;
 	if (!$req) {
-		(my $path = $t->request->uri->path) =~ s/\/$//;
+		(my $path = $t->request->uri->path) =~ s/^\/|\/$//g;
 		if ($self->controllers->{_alias}) {
 			for my $candidate (keys %{$self->controllers->{_alias}}) {
                         	my @captured = $path =~ m/^$candidate$/;
                         	if (scalar @captured) {
                                 	$t->captured = \@captured;
                                 	$t->params->req = $req = $self->controllers->{_alias}->{$candidate}->{req};
-                        	}
+                        		last;
+				}
                 	}
 		}
 		$req = $self->SUPER::preprocess_req($req, $t) if ! $req;
@@ -199,7 +200,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
